=======
History
=======

`Unreleased`_
=============

`1.1.2`_ (2023-08-31)
=====================

* Fix migration dependency from django-cms due to new migrations in django-cms v3. `#32`_

`1.1.1`_ (2023-03-24)
=====================

* Fix migration dependency from django-cms. `#21`_

`1.1.0`_ (2022-07-27)
=====================

* Added python 3.10 support. `#11`_

`1.0.1`_ (2022-03-02)
=====================

* Added ``py.typed`` and removed v4 cms restriction `#1`_

`1.0.0`_ (2022-03-02)
=====================

* First release.

.. _1.0.0: https://github.com/marksweb/djangocms-ads/tree/1.0.0
.. _1.0.1: https://github.com/marksweb/djangocms-ads/compare/1.0.0...1.0.1
.. _1.1.0: https://github.com/marksweb/djangocms-ads/compare/1.0.1...1.1.0
.. _1.1.1: https://github.com/marksweb/djangocms-ads/compare/1.1.0...1.1.1
.. _Unreleased: https://github.com/marksweb/djangocms-ads/compare/1.1.1...master

.. _#1: https://github.com/marksweb/djangocms-ads/pull/1
.. _#11: https://github.com/marksweb/djangocms-ads/pull/11
.. _#21: https://github.com/marksweb/djangocms-ads/pull/21
.. _#32: https://github.com/marksweb/djangocms-ads/pull/32
